pub struct OwnedLinearMemorySpec {
pub heap: HeapSpec,
pub initializer: OwnedSparseData,
}Expand description
Specification of the linear memory of a module
This is a version of LinearMemorySpec with an
OwnedSparseData for the initializer.
This type is useful when directly building up a value to be serialized.
Fields
heap: HeapSpecSpecification of the heap used to implement the linear memory
initializer: OwnedSparseDataInitialization values for linear memory
Implementations
Sourceimpl OwnedLinearMemorySpec
impl OwnedLinearMemorySpec
pub fn to_ref<'a>(&'a self) -> LinearMemorySpec<'a>